@@ -466,68 +466,6 @@ for (n in c(20, 100, 500)){
       "\nse = ", round(mean(sample.se), digits = 2), sep = ""))
 }
 
-
-### JetLagKnees
-
-# Subset the three treatment groups
-control <- subset(JetLagKnees, treatment == "control")$shift
-knee <- subset(JetLagKnees, treatment == "knee")$shift
-eyes <- subset(JetLagKnees, treatment == "eyes")$shift
-
-# k is the number of groups
-k <- length(unique(JetLagKnees$treatment))
-
-# Calculate n
-n <- length(JetLagKnees$shift)
-control.n <- length(control)
-knee.n <- length(knee)
-eyes.n <- length(eyes)
-
-# Calculate standard deviations
-control.sd <- sd(control)
-knee.sd <- sd(knee)
-eyes.sd <- sd(eyes)
-
-(SS.error <- ((control.sd^2 * (control.n - 1)) +
-  (knee.sd^2 * (knee.n - 1)) +
-  (eyes.sd^2 * (eyes.n - 1))))
-(MS.error <- SS.error / (n - k))
-
-(grand.mean <- (control.n * mean(control) + knee.n * mean(knee) + 
-  eyes.n * mean(eyes)) / n)
-
-(SS.groups <- (control.n * (mean(control) - grand.mean)^2) +
-              (knee.n * (mean(knee) - grand.mean)^2) +
-              (eyes.n * (mean(eyes) - grand.mean)^2))
-(MS.groups <- SS.groups / (k - 1))
-
-(F <- MS.groups / MS.error)
-
-pf(F, 2, 19, lower.tail = FALSE)
-
-# Shade area under the curve for the F(2, 19) distribution
-dev.new()
-par(xaxs = "i", yaxs = "i")
-(fcrit <- qf(0.05, 2, 19, lower.tail = FALSE))
-curve(df(x, 2, 19), from = 0, to = 10,
-  ylab = "Probability Density", 
-  xlab = expression(F[paste("2,19")]))
-x <- seq(fcrit, 10, length = 100)
-y <- df(x, 2, 19)
-polygon(c(x[1], x, x[100]), c(0, y, df(10, 2, 19)),
-     col = "red", border = NA)
-
-# R^2
-(SS.total <- SS.groups + SS.error)
-SS.groups/SS.total
-
-# With aov()
-aov.obj <- aov(shift ~ treatment, data = JetLagKnees)
-
-# Compare the output of print() and summary()
-aov.obj
-summary(aov.obj)
-
 ### LionNoses
 plot(LionNoses$proportion.black, LionNoses$age,
   xlab = "Proportion black",
@@ -625,12 +563,7 @@ exp(cis)
 ### MassExtinctions
 if(0){
 # Calculate weighted mean
-# with expand.dft()
-n.extinctions <- expand.dft(MassExtinctions,
-  "count")$Number.of.extinctions
-wt.mean <- mean(n.extinctions)
-
-# With weighted.mean()
+# with weighted.mean()
 (wt.mean <- weighted.mean(MassExtinctions$Number.of.extinctions,
   MassExtinctions$Frequency))
 
@@ -933,39 +866,6 @@ try({
 	}
 )
 
-### WalkingStickFemurs
-data(WalkingStickFemurs)
-str(WalkingStickFemurs)
-
-aovfit <- aov(femur.length ~ specimen, data = WalkingStickFemurs)
-aovfit
-(aov.summary <- summary(aovfit))
-MS.groups <- aov.summary[[1]]$"Mean Sq"[1]
-MS.error <- aov.summary[[1]]$"Mean Sq"[2]
-
-# Among-group variance
-(var.among <- (MS.groups - MS.error) / 2)
-
-# Repeatability or Intraclass Correlation
-var.among / (var.among + MS.error)
-
-# Can use Error() with varcomps() and repeatability()
-aovfit2 <- aov(femur.length ~ 1 + Error(specimen),
-  data = WalkingStickFemurs)
-vc <- varcomps(aovfit2, n = 2)
-vc
-R.varcomps <- repeatability(vc)
-R.varcomps
-
-# The same model can be fit with lme()
-require(nlme)
-lme.fit <- lme(femur.length ~ 1, random = ~ 1 | specimen,
-  data = WalkingStickFemurs)
-summary(lme.fit)
-VarCorr(lme.fit)
-R.lme <- repeatability(lme.fit)
-R.lme
-
 ### Wolves
 # Plot with jitter() to separate integer numbers of pups on y axis
 plot(jitter(pups) ~ inbreeding.coefficient, data = Wolves,
